@@ -7,14 +7,15 @@
 // Mocking Util
 void reset_mocking();
 void init_mocking(MOCK_METHOD mock_style, int starting_value);
+void mocking_tick();
 
 // Random Functions
 int random_fn(int small, int big );
 
 // Rolling Functions
 int * perform_roll(
-    int number_of_dice,
-    int die_sides,
+    unsigned int number_of_dice,
+    unsigned int die_sides,
     EXPLOSION_TYPE explode,
     int start_value
 );
@@ -22,7 +23,5 @@ int * do_roll(
     roll_params rp
 );
 
-// Verification
-int validate_roll(int number_of_dice, int die_side);
 
-#endif
\ No newline at end of file
+#endif
