@@ -5,29 +5,31 @@
 #include "rolls/dice_enums.h"
 #include "rolls/vec.h"
 
-void initialize_vector(vec * vector, DIE_TYPE dt, int num);
+void initialize_vector(vec * vector, DIE_TYPE dt, unsigned int number_of_items);
 
-void pop(int * arr, int len, int value, int * new_arr);
+void pop(int * arr, unsigned int len, int value, int * new_arr);
 
-int min(int * arr, int len);
-int max(int * arr, int len);
+int contains(int * arr, unsigned int len, int value);
+int min(int * arr, unsigned int len);
+int max(int * arr, unsigned int len);
 
-void concat_symbols(char ** arr1, int len1,
-                    char ** arr2, int len2,
+void concat_symbols(char ** arr1, unsigned int len1,
+                    char ** arr2, unsigned int len2,
                     char ** new_arr);
 
-unsigned int remove_if_present(char ** arr1, int len1,
-                    char ** arr2, int len2,
+unsigned int remove_if_present(char ** arr1, unsigned int len1,
+                    char ** arr2, unsigned int len2,
                     char ** new_arr);
 
 void collapse_vector(vec * vector, vec * new_vector);
 
+unsigned int keep_logic(vec * vector, vec * new_vector, unsigned int number_to_keep, int keep_high);
 unsigned int keep_highest_values(vec * vector, vec * new_vector, unsigned int number_to_keep);
 unsigned int keep_lowest_values(vec * vector, vec * new_vector, unsigned int number_to_keep);
 unsigned int drop_highest_values(vec * vector, vec * new_vector, unsigned int number_to_keep);
 unsigned int drop_lowest_values(vec * vector, vec * new_vector, unsigned int number_to_keep);
 
-void extract_symbols(char ** symbols_list, char ** result_symbols, int * indexes, int idx_length);
+void extract_symbols(char ** symbols_list, char ** result_symbols, int * indexes, unsigned int idx_length);
 
 void print_vec(vec vector);
 
@@ -35,4 +37,4 @@ void filter(vec * dice, vec * cond, int comparitor, vec * output);
 
 void filter_unique(vec * dice, vec * new_vec);
 
-#endif
\ No newline at end of file
+#endif
